@@ -8,9 +8,9 @@ class Review(models.Model):
     visible = models.BooleanField(default=True)
     sortorder = models.IntegerField(default=999)
     reviewer = models.TextField(max_length=80)
-    entity = models.TextField(max_length=80)
-    citation = models.TextField(max_length=255)
-    url = models.URLField()
+    entity = models.TextField(blank=True, max_length=80)
+    citation = models.TextField(blank=True, max_length=255)
+    url = models.URLField(blank=True)
     body = RichTextField()
 
 class Quote(models.Model):
